==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
export let ChartSummaryDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSummaryDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
                ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
            }
            if (a.g(ChartSummaryDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.s(ChartSummaryDescriptionDescriptionMetadata.a);
            ProvideCalculatorEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("Operand", "ExportedType:string:SummaryOperand");
            a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("Alias", "String");
            a.item("CalculatorDisplayName", "String");
            a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
        }
        static d(a) {
            ChartSummaryDescriptionDescriptionMetadata.b(a);
            a.u("ChartSummaryDescription", () => new ChartSummaryDescriptionDescription());
            a.t("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
        }
    }
    ChartSummaryDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
export let ChartSummaryDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSummaryDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
                ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
            }
            if (a.j(ChartSummaryDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.y(ChartSummaryDescriptionDescriptionMetadata.a);
            ProvideCalculatorEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Field", "String");
            a.item("Operand", "ExportedType:string:DataSourceSummaryOperand");
            a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("Alias", "String");
            a.item("CalculatorDisplayName", "String");
            a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
        }
        static d(a) {
            ChartSummaryDescriptionDescriptionMetadata.b(a);
            a.aa("ChartSummaryDescription", () => new ChartSummaryDescriptionDescription());
            a.z("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
        }
    }
    ChartSummaryDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
})();
